@@ -1,20 +1,16 @@
 from unitgrade.evaluate import evaluate_report, python_code_str_id
-import lzma
-import base64
 import textwrap
-import hashlib
 import bz2
 import pickle
 import os
 import zipfile
 import io
-
+from unitgrade.utils import picklestring2dict, dict2picklestring, load_token, token_sep
 
 def bzwrite(json_str, token): # to get around obfuscation issues
     with getattr(bz2, 'open')(token, "wt") as f:
         f.write(json_str)
 
-
 def gather_imports(imp):
     resources = {}
     m = imp
@@ -96,23 +92,13 @@ def gather_report_source_include(report):
             print(f" * {m.__name__}")
     return sources
 
-# def report_script_relative_location(report):
-#     """
-#     Given the grade script corresponding to the 'report', work out it's relative location either compared to the
-#     package it is in or directory.
-#     """
-#     if len(report.individual_imports) == 0:
-#         return "./"
-#     else:
-#
-#     pass
-
 def gather_upload_to_campusnet(report, output_dir=None, token_include_plaintext_source=False):
     # n = report.nL
     args = parser.parse_args()
     results, table_data = evaluate_report(report, show_help_flag=False, show_expected=False, show_computed=False, silent=True,
                                           show_progress_bar=not args.noprogress,
                                           big_header=not args.autolab,
+                                          generate_artifacts=False,
                                           )
     print("")
     sources = {}
@@ -168,20 +154,6 @@ def gather_upload_to_campusnet(report, output_dir=None, token_include_plaintext_
         print(">", token)
 
 
-
-def dict2picklestring(dd):
-    b = lzma.compress(pickle.dumps(dd))
-    b_hash = hashlib.blake2b(b).hexdigest()
-    return base64.b64encode(b).decode("utf-8"), b_hash
-
-def picklestring2dict(picklestr):
-    b = base64.b64decode(picklestr)
-    hash = hashlib.blake2b(b).hexdigest()
-    dictionary = pickle.loads(lzma.decompress(b))
-    return dictionary, hash
-
-
-token_sep = "-"*70 + " ..ooO0Ooo.. " + "-"*70
 def save_token(dictionary, plain_text, file_out):
     if plain_text is None:
         plain_text = ""
@@ -197,23 +169,7 @@ def save_token(dictionary, plain_text, file_out):
     with open(file_out, 'w') as f:
         f.write("\n".join(out))
 
-def load_token(file_in):
-    with open(file_in, 'r') as f:
-        s = f.read()
-    splt = s.split(token_sep)
-    data = splt[-1]
-    info = splt[-2]
-    head = token_sep.join(splt[:-2])
-    plain_text=head.strip()
-    hash, l1 = info.split(" ")
-    data = "".join( data.strip()[1:-1].splitlines() )
-    l1 = int(l1)
 
-    dictionary, b_hash = picklestring2dict(data)
-
-    assert len(data) == l1
-    assert b_hash == hash.strip()
-    return dictionary, plain_text
 
 
 def source_instantiate(name, report1_source, payload):
